@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ This is the main actions of Nuitka.
 
 This can do all the steps to translate one module to a target language using
@@ -28,7 +14,11 @@ import os
 import sys
 
 from nuitka.build.DataComposerInterface import runDataComposer
-from nuitka.build.SconsUtils import getSconsReportValue, readSconsReport
+from nuitka.build.SconsUtils import (
+    getSconsReportValue,
+    readSconsErrorReport,
+    readSconsReport,
+)
 from nuitka.code_generation.ConstantCodes import (
     addDistributionMetadataValue,
     getDistributionMetadataValues,
@@ -289,7 +279,7 @@ def dumpTreeXML():
     filename = Options.getXMLDumpOutputFilename()
 
     if filename is not None:
-        with openTextFile(filename, "w") as output_file:
+        with openTextFile(filename, "wb") as output_file:
             # XML output only.
             for module in ModuleRegistry.getDoneModules():
                 dumpTreeXMLToFile(tree=module.asXml(), output_file=output_file)
@@ -566,7 +556,7 @@ def _runPythonPgoBinary():
 
     if not os.path.exists(pgo_filename):
         general.sysexit(
-            "Error, no Python PGO information produced, did the created binary (exit code %d) as expected?"
+            "Error, no Python PGO information produced, did the created binary run (exit code %d) as expected?"
             % exit_code
         )
 
@@ -583,6 +573,7 @@ def runSconsBackend():
         "source_dir": OutputDirectories.getSourceDirectoryPath(),
         "nuitka_python": asBoolStr(isNuitkaPython()),
         "debug_mode": asBoolStr(Options.is_debug),
+        "debugger_mode": asBoolStr(Options.shallRunInDebugger()),
         "python_debug": asBoolStr(Options.shallUsePythonDebug()),
         "module_mode": asBoolStr(Options.shallMakeModule()),
         "full_compat": asBoolStr(Options.is_full_compat),
@@ -768,12 +759,7 @@ def runSconsBackend():
     return result
 
 
-def callExecPython(args, clean_path, add_path):
-    old_python_path = os.getenv("PYTHONPATH")
-
-    if clean_path and old_python_path is not None:
-        os.environ["PYTHONPATH"] = ""
-
+def callExecPython(args, add_path):
     if add_path:
         if "PYTHONPATH" in os.environ:
             os.environ["PYTHONPATH"] += ":" + Options.getOutputDir()
@@ -786,17 +772,17 @@ def callExecPython(args, clean_path, add_path):
     callExecProcess(args)
 
 
-def executeMain(binary_filename, clean_path):
+def _executeMain(binary_filename):
     # Wrap in debugger, unless the CMD file contains that call already.
     if Options.shallRunInDebugger() and not Options.shallCreateCmdFileForExecution():
         args = wrapCommandForDebuggerForExec(binary_filename)
     else:
         args = (binary_filename, binary_filename)
 
-    callExecPython(clean_path=clean_path, add_path=False, args=args)
+    callExecPython(add_path=False, args=args)
 
 
-def executeModule(tree, clean_path):
+def _executeModule(tree):
     """Execute the extension module just created."""
 
     if python_version < 0x340:
@@ -838,7 +824,7 @@ import sys; sys.path.insert(0, %(output_dir)r)
     else:
         args = (sys.executable, "python", "-c", python_command)
 
-    callExecPython(clean_path=clean_path, add_path=True, args=args)
+    callExecPython(add_path=True, args=args)
 
 
 def compileTree():
@@ -851,9 +837,11 @@ def compileTree():
 
         reportMemoryUsage(
             "before_c_code_generation",
-            "Total memory usage before generating C code:"
-            if Options.isShowProgress() or Options.isShowMemory()
-            else None,
+            (
+                "Total memory usage before generating C code:"
+                if Options.isShowProgress() or Options.isShowMemory()
+                else None
+            ),
         )
 
         # Now build the target language code for the whole tree.
@@ -879,9 +867,11 @@ def compileTree():
 
     reportMemoryUsage(
         "before_running_scons",
-        "Total memory usage before running scons"
-        if Options.isShowProgress() or Options.isShowMemory()
-        else None,
+        (
+            "Total memory usage before running scons"
+            if Options.isShowProgress() or Options.isShowMemory()
+            else None
+        ),
     )
 
     if Options.isShowMemory():
@@ -962,9 +952,11 @@ def _main():
 
     reportMemoryUsage(
         "after_launch",
-        "Total memory usage before processing:"
-        if Options.isShowProgress() or Options.isShowMemory()
-        else None,
+        (
+            "Total memory usage before processing:"
+            if Options.isShowProgress() or Options.isShowMemory()
+            else None
+        ),
     )
 
     # Initialize the importing layer from options, main filenames, debugging
@@ -989,7 +981,11 @@ def _main():
 
     # Exit if compilation failed.
     if not result:
-        general.sysexit(exit_code=1, reporting=True)
+        general.sysexit(
+            message="Failed unexpectedly in Scons C backend compilation.",
+            mnemonic="scons-backend-failure",
+            reporting=True,
+        )
 
     # Relaunch in case of Python PGO input to be produced.
     if Options.shallCreatePgoInput():
@@ -1009,8 +1005,6 @@ def _main():
 
     executePostProcessing()
 
-    copyDataFiles()
-
     if Options.isStandaloneMode():
         binary_filename = scons_options["result_exe"]
 
@@ -1031,6 +1025,10 @@ def _main():
             standalone_entry_points=getStandaloneEntryPoints(),
         )
 
+    copyDataFiles(standalone_entry_points=getStandaloneEntryPoints())
+
+    if Options.isStandaloneMode():
+
         Plugins.onStandaloneDistributionFinished(dist_dir)
 
         if Options.isOnefileMode():
@@ -1054,6 +1052,8 @@ def _main():
 
         # Make sure the scons report is cached before deleting it.
         readSconsReport(source_dir)
+        readSconsErrorReport(source_dir)
+
         removeDirectory(path=source_dir, ignore_errors=False)
         assert not os.path.exists(source_dir)
     else:
@@ -1108,15 +1108,9 @@ not use compiled code while it exists."""
         general.info("Launching '%s'." % run_filename)
 
         if Options.shallMakeModule():
-            executeModule(
-                tree=main_module,
-                clean_path=Options.shallClearPythonPathEnvironment(),
-            )
+            _executeModule(tree=main_module)
         else:
-            executeMain(
-                binary_filename=run_filename,
-                clean_path=Options.shallClearPythonPathEnvironment(),
-            )
+            _executeMain(run_filename)
     else:
         if run_filename != final_filename:
             general.info(
@@ -1143,3 +1137,19 @@ Report writing was prevented by exception %r, use option \
                 raise
 
         raise
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
