@@ -1,20 +1,6 @@
-#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ XML node tree handling
 
 Means to create XML elements from Nuitka tree nodes and to convert the
@@ -71,13 +57,13 @@ try:
 
     Element = xml.etree.ElementTree.Element
 
-    def xml_tostring(tree, indent=True):
+    def xml_tostring(tree, indent=True, encoding=None):
         if indent:
             _indent(tree)
         elif not indent:
             _dedent(tree)
 
-        return xml_module.tostring(tree)
+        return xml_module.tostring(tree, encoding=encoding)
 
 except ImportError:
     xml_module = None
@@ -94,12 +80,12 @@ except ImportError:
 #     xml_writer = None
 
 
-def toBytes(tree, indent=True):
-    return xml_tostring(tree, indent=indent)
+def toBytes(tree, indent=True, encoding=None):
+    return xml_tostring(tree, indent=indent, encoding=encoding)
 
 
 def toString(tree):
-    result = toBytes(tree)
+    result = toBytes(tree, encoding="utf8")
 
     if str is not bytes:
         result = result.decode("utf8")
@@ -131,5 +117,21 @@ def appendTreeElement(parent, *args, **kwargs):
 def dumpTreeXMLToFile(tree, output_file):
     """Write an XML node tree to a file."""
 
-    value = toString(tree).rstrip()
+    value = toBytes(tree).rstrip()
     output_file.write(value)
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
