@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """DLL dependency scan methods for Win32 Windows.
 
 Note: MSYS2, aka POSIX Windows is dealt with in the "DllDependenciesPosix" module.
@@ -28,6 +14,7 @@ from nuitka.build.SconsUtils import readSconsReport
 from nuitka.containers.OrderedSets import OrderedSet
 from nuitka.Options import isShowProgress
 from nuitka.plugins.Plugins import Plugins
+from nuitka.PythonVersions import getSystemPrefixPath
 from nuitka.Tracing import inclusion_logger
 from nuitka.utils.AppDirs import getCacheDir
 from nuitka.utils.FileOperations import (
@@ -50,7 +37,7 @@ from .DllDependenciesCommon import getPackageSpecificDLLDirectories
 _scan_dir_cache = {}
 
 
-def detectBinaryPathDLLsWindowsDependencyWalker(
+def detectBinaryPathDLLsWin32(
     is_main_executable,
     source_dir,
     original_dir,
@@ -113,7 +100,7 @@ def _getScanDirectories(package_name, original_dir):
     if cache_key in _scan_dir_cache:
         return _scan_dir_cache[cache_key]
 
-    scan_dirs = [sys.prefix]
+    scan_dirs = [getSystemPrefixPath()]
 
     if package_name is not None:
         scan_dirs.extend(getPackageSpecificDLLDirectories(package_name))
@@ -200,7 +187,23 @@ def _getCacheFilename(
     # Take Nuitka version into account as well, ought to catch code changes.
     hash_value.updateFromValues(version_string)
 
-    cache_dir = os.path.join(getCacheDir(), "library_dependencies", dependency_tool)
+    cache_dir = os.path.join(getCacheDir("library_dependencies"), dependency_tool)
     makePath(cache_dir)
 
     return os.path.join(cache_dir, hash_value.asHexDigest())
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
