@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Module/Package nodes
 
 The top of the tree. Packages are also modules. Modules are what hold a program
@@ -57,6 +43,7 @@ class PythonModuleBase(NodeBase):
 
     def __init__(self, module_name, reason, source_ref):
         assert type(module_name) is ModuleName, module_name
+        assert module_name != "", source_ref
 
         NodeBase.__init__(self, source_ref=source_ref)
 
@@ -144,7 +131,7 @@ class PythonModuleBase(NodeBase):
             )
 
     def getCodeName(self):
-        # Abstract method, pylint: disable=no-self-use
+        # Virtual method, pylint: disable=no-self-use
         return None
 
     def getCompileTimeFilename(self):
@@ -205,6 +192,13 @@ class PythonModuleBase(NodeBase):
 
                 result = os.path.join(os.path.basename(current), result)
 
+            # Avoid unnecessary unicode path values
+            if str is not bytes:
+                try:
+                    result = str(result)
+                except UnicodeDecodeError:
+                    pass
+
             return result
 
 
@@ -456,7 +450,10 @@ class CompiledPythonModule(
         # For code name of modules, we need to translate to C identifiers,
         # removing characters illegal for that.
 
-        return encodePythonIdentifierToC(self.getFullName())
+        if self.code_name is None:
+            self.code_name = encodePythonIdentifierToC(self.module_name)
+
+        return self.code_name
 
     @staticmethod
     def getChildQualname(function_name):
@@ -546,9 +543,11 @@ class CompiledPythonModule(
 
         self.trace_collection = TraceCollectionModule(
             self,
-            very_trusted_module_variables=old_collection.getVeryTrustedModuleVariables()
-            if old_collection is not None
-            else {},
+            very_trusted_module_variables=(
+                old_collection.getVeryTrustedModuleVariables()
+                if old_collection is not None
+                else {}
+            ),
         )
 
         module_body = self.subnode_body
@@ -1077,3 +1076,19 @@ class PythonExtensionModule(PythonModuleBase):
 
     def getParentModule(self):
         return self
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
