@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Trace collection (also often still referred to as constraint collection).
 
 At the core of value propagation there is the collection of constraints that
@@ -31,8 +17,6 @@ from nuitka import Variables
 from nuitka.__past__ import iterItems  # Python3 compatibility.
 from nuitka.containers.OrderedDicts import OrderedDict
 from nuitka.containers.OrderedSets import OrderedSet
-from nuitka.importing.Importing import locateModule, makeModuleUsageAttempt
-from nuitka.importing.Recursion import decideRecursion
 from nuitka.ModuleRegistry import addUsedModule
 from nuitka.nodes.NodeMakingHelpers import getComputationResult
 from nuitka.nodes.shapes.StandardShapes import tshape_uninitialized
@@ -802,7 +786,7 @@ class TraceCollectionBase(object):
 
                 if trace1.isEscapeTrace() and trace1.previous is trace2:
                     version = versions[0]
-                elif trace2 is trace1.isEscapeTrace() and trace2.previous is trace1:
+                elif trace2.isEscapeTrace() and trace2.previous is trace1:
                     version = versions[1]
                 else:
                     version = self.addVariableMergeMultipleTrace(
@@ -963,6 +947,9 @@ class TraceCollectionBase(object):
     def onUsedFunction(self, function_body):
         return self.parent.onUsedFunction(function_body)
 
+    def onModuleUsageAttempts(self, module_usage_attempts):
+        self.parent.onModuleUsageAttempts(module_usage_attempts)
+
     def onModuleUsageAttempt(self, module_usage_attempt):
         self.parent.onModuleUsageAttempt(module_usage_attempt)
 
@@ -1073,7 +1060,7 @@ class TraceCollectionFunction(CollectionStartPointMixin, TraceCollectionBase):
         if trusted_node is None:
             return CollectionStartPointMixin.initVariableModule(self, variable)
 
-        assign_trace = ValueTraceAssign(
+        assign_trace = ValueTraceAssignVeryTrusted(
             self.owner, assign_node=trusted_node.getParent(), previous=None
         )
 
@@ -1147,60 +1134,10 @@ class TraceCollectionModule(CollectionStartPointMixin, TraceCollectionBase):
     def getModuleUsageAttempts(self):
         return self.module_usage_attempts
 
+    def onModuleUsageAttempts(self, module_usage_attempts):
+        self.module_usage_attempts.update(module_usage_attempts)
+
     def onModuleUsageAttempt(self, module_usage_attempt):
-        if module_usage_attempt.finding != "not-found":
-            decision, _reason = decideRecursion(
-                using_module_name=self.owner.getFullName(),
-                module_name=module_usage_attempt.module_name,
-                module_filename=module_usage_attempt.filename,
-                module_kind=module_usage_attempt.module_kind,
-            )
-
-            # When sub-package module import is rejected for whatever reason,
-            # still this implies an attempt of the parent, because nothing else
-            # will do it otherwise, it of course may also be rejected, but if it
-            # is not, otherwise it will be missing.
-            #
-            # A common case of this happening are extension modules in
-            # accelerated mode, for standalone this will of course be rare.
-            if decision is False:
-                parent_package_name = module_usage_attempt.module_name.getPackageName()
-
-                if parent_package_name is not None:
-                    (
-                        package_module_name,
-                        module_filename,
-                        module_kind,
-                        finding,
-                    ) = locateModule(
-                        module_name=parent_package_name,
-                        parent_package=None,
-                        level=0,
-                    )
-
-                    # Should not be possible to happen.
-                    assert finding != "not-found", package_module_name
-
-                    decision, _reason = decideRecursion(
-                        using_module_name=self.owner.getFullName(),
-                        module_name=package_module_name,
-                        module_filename=module_filename,
-                        module_kind=module_kind,
-                    )
-
-                    if decision is True:
-                        self.onModuleUsageAttempt(
-                            makeModuleUsageAttempt(
-                                module_name=package_module_name,
-                                filename=module_filename,
-                                finding=finding,
-                                module_kind=module_kind,
-                                level=0,
-                                source_ref=module_usage_attempt.source_ref,
-                                reason="parent import",
-                            )
-                        )
-
         self.module_usage_attempts.add(module_usage_attempt)
 
     def getUsedDistributions(self):
@@ -1287,3 +1224,19 @@ def areReadOnlyTraces(variable_traces):
             assert False, variable_trace
 
     return True
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
