@@ -1,20 +1,6 @@
-#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Standard plug-in to find data files.
 
 """
@@ -23,25 +9,23 @@ import os
 import pkgutil
 
 from nuitka import Options
+from nuitka.code_generation.ConstantCodes import addDistributionMetadataValue
 from nuitka.containers.OrderedSets import OrderedSet
-from nuitka.plugins.PluginBase import NuitkaPluginBase
+from nuitka.plugins.PluginBase import NuitkaYamlPluginBase
 from nuitka.PythonFlavors import isDebianPackagePython
+from nuitka.utils.Distributions import getDistribution
 from nuitka.utils.FileOperations import (
     changeFilenameExtension,
     getFileList,
     resolveShellPatternToFilenames,
 )
-from nuitka.utils.Yaml import getYamlPackageConfiguration
 
 
-class NuitkaPluginDataFileCollector(NuitkaPluginBase):
+class NuitkaPluginDataFileCollector(NuitkaYamlPluginBase):
     plugin_name = "data-files"
 
     plugin_desc = "Include data files specified by package configuration files."
 
-    def __init__(self):
-        self.config = getYamlPackageConfiguration()
-
     @classmethod
     def isRelevant(cls):
         return Options.isStandaloneMode()
@@ -52,7 +36,7 @@ class NuitkaPluginDataFileCollector(NuitkaPluginBase):
 
     def _considerDataFiles(self, module, data_file_config):
         # Many details and cases to deal with
-        # pylint: disable=too-many-branches,too-many-locals
+        # pylint: disable=too-many-branches,too-many-locals,too-many-statements
 
         module_name = module.getFullName()
         module_folder = module.getCompileTimeDirectory()
@@ -81,6 +65,14 @@ class NuitkaPluginDataFileCollector(NuitkaPluginBase):
 
             # TODO: Pattern should be data file kind potentially.
             for pattern in patterns:
+                pattern = self.evaluateExpressionOrConstant(
+                    full_name=module_name,
+                    expression=pattern,
+                    config_name="data file pattern for '%s'" % module_name,
+                    extra_context=None,
+                    single_value=True,
+                )
+
                 pattern = os.path.join(module_folder, pattern)
 
                 for filename in resolveShellPatternToFilenames(pattern):
@@ -168,6 +160,14 @@ class NuitkaPluginDataFileCollector(NuitkaPluginBase):
                     tags="config",
                 )
 
+        distribution_names = data_file_config.get("include-metadata", ())
+
+        for distribution_name in distribution_names:
+            distribution = getDistribution(distribution_name)
+
+            if distribution is not None:
+                addDistributionMetadataValue(distribution_name, distribution)
+
     def considerDataFiles(self, module):
         full_name = module.getFullName()
 
@@ -263,3 +263,19 @@ class NuitkaPluginDataFileCollector(NuitkaPluginBase):
                 reason="Subdirectories of module %s" % module.getFullName(),
                 tags="config",
             )
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
