@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Read/write source code from files.
 
 Reading is tremendously more complex than one might think, due to encoding
@@ -299,6 +285,7 @@ That will make use the correct Python version for Nuitka.
 
 
 def readSourceLine(source_ref):
+    """Read a single source line, mainly for use in error reporting only."""
     import linecache
 
     return linecache.getline(
@@ -306,6 +293,13 @@ def readSourceLine(source_ref):
     )
 
 
+def readSourceLines(source_ref):
+    """Read a source lines with linecache, for use with cached function source finding."""
+    import linecache
+
+    return linecache.getlines(source_ref.filename)
+
+
 def writeSourceCode(filename, source_code):
     # Prevent accidental overwriting. When this happens the collision detection
     # or something else has failed.
@@ -416,3 +410,19 @@ def parsePyIFile(module_name, pyi_filename):
                     pyi_deps.add(in_import_part + "." + name)
 
     return pyi_deps
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
